% TU Delft iGEM team
% Aug 2008
% Mevalonate pathway ODEs function

function xdot = mevalonate(time,x)
%  synopsis:
%     xdot = mevalonate (time, x)
%     x0 = mevalonate
%
%  mevalonate can be used with odeN functions as follows:
%
%  x0 = mevalonate;
%  [t,x] = ode23s(@mevalonate, [0 100], mevalonate);
%  plot (t,x);
%
%  where 100 is the end time
%
%  When mevalonate is used without any arguments it returns a vector of
%  the initial concentrations of the 30 floating species.
%  Otherwise mevalonate should be called with two arguments:
%  time and x.  time is the current time. x is the vector of the
%  concentrations of the 30 floating species.
%  When these parameters are supplied mevalonate returns a vector of 
%  the rates of change of the concentrations of the 30 floating species.
%
%  the following table shows the mapping between the vector
%  index of a floating species and the species name.
%  
%  NOTE for compartmental models
%  matlab translator generates code that when simulated in matlab, 
%  produces results which have the units of species amounts. Users 
%  should divide the results for each species with the volume of the
%  compartment it resides in, in order to obtain concentrations.
%  
%  Indx      Name
%  x(1)        s1
%  x(2)        s2
%  x(3)        s3
%  x(4)        s4
%  x(5)        s5
%  x(6)        s6
%  x(7)        s7
%  x(8)        s8
%  x(9)        s9
%  x(10)       s10
%  x(11)       s11
%  x(12)       s12
%  x(13)       s13
%  x(14)       s14
%
%  x(15)       s15
%  x(16)       s16
%  x(17)       s17
%  x(18)       s18
%  x(19)       s19
%  x(20)       s20
%  x(21)       s21
%  x(22)       s22
%  x(23)       s23
%  x(24)       s24
%  x(25)       s25
%  x(26)       s26
%  x(27)       s27
%
%  x(28)       s28
%  x(29)       s29
%  x(30)       s30

xdot = zeros(30, 1);

% List of Compartments 
vol__default = 1;

% Other Parameters
par_r1_p1 = 0.1;		% [re1, v1]
par_r1_p2 = 0.1;		% [re1, k1]
par_r2_p1 = 0.1;		% [re2, v2]
par_r2_p2 = 0.1;		% [re2, k2]
par_r3_p1 = 0.1;		% [re3, k3]
par_r3_p2 = 0.1;		% [re3, v3]
par_r4_p1 = 0.1;		% [re4, k4]
par_r4_p2 = 0.1;		% [re4, v4]
par_r5_p1 = 0.1;		% [re5, k5]
par_r5_p2 = 0.1;		% [re5, v5]
par_r6_p1 = 0.1;		% [re7, k6]
par_r6_p2 = 0.1;		% [re7, v6]
par_r7_p1 = 0.1;		% [re8, k7]
par_r7_p2 = 0.2;		% [re8, v7]
par_r8_p1 = 0.1;		% [re9, k8]
par_r8_p2 = 0.1;		% [re9, v8]
par_r9_p1 = 0.1;		% [re10, k9]
par_r9_p2 = 0.1;		% [re10, v9]
par_r10_p1 = 0.1;		% [re11, k10]
par_r10_p2 = 0.1;		% [re11, v10]
par_r11_p1 = 0.1;		% [re12, k11]
par_r11_p2 = 0.1;		% [re12, v11]
par_r12_p1 = 0.1;		% [re13, k12]
par_r12_p2 = 0.1;		% [re13, v12]
par_r13_p1 = 0.1;		% [re14, k13]
par_r13_p2 = 0.1;		% [re14, v13]
par_r14_p1 = 0.1;		% [re15, k14]
par_r14_p2 = 0.1;		% [re15, v14]
par_r15_p1 = 0.1;		% [re19, d1]
par_r16_p1 = 0.1;		% [re21, d2]
par_r17_p1 = 0.1;		% [re23, d3]
par_r17_p2 = 0.1;

if (nargin == 0)
    % set initial conditions
   xdot(1) = 0.1;		% s1 [Amount]
   xdot(2) = 0;		% s2 [Amount]
   xdot(3) = 0;		% s3 [Amount]
   xdot(4) = 0;		% s4 [Amount]
   xdot(5) = 0.01;		% s5 [Amount]
   xdot(6) = 0.01;		% s6 [Amount]
   xdot(7) = 0;		% s8 [Amount]
   xdot(8) = 0.01;		% s9 [Amount]
   xdot(9) = 0;		% s10 [Amount]
   xdot(10) = 0.01;		% s11 [Amount]
   xdot(11) = 0;		% s12 [Amount]
   xdot(12) = 0.01;		% s13 [Amount]
   xdot(13) = 0;		% s14 [Amount]
   xdot(14) = 0.01;		% s15 [Amount]
   xdot(15) = 0;		% s16 [Amount]
   xdot(16) = 0.01;		% s17 [Amount]
   xdot(17) = 0.01;		% s7 [Amount]
   xdot(18) = 0;		% s18 [Amount]
   xdot(19) = 0.01;		% s23 [Amount]
   xdot(20) = 0;		% s19 [Amount]
   xdot(21) = 0.01;		% s24 [Amount]
   xdot(22) = 0;		% s21 [Amount]
   xdot(23) = 0;		% s25 [Amount]
   xdot(24) = 0.01;		% s26 [Amount]
   xdot(25) = 0.01;		% s27 [Amount]
   xdot(26) = 0;		% s28 [Amount]
   xdot(27) = 0.01;		% s29 [Amount]
   xdot(28) = 0;		% s32 [Amount]
   xdot(29) = 0;		% s34 [Amount]
   xdot(30) = 0;		% s36 [Amount]
else
    % calculate rates of change
   R0 = par_r1_p1*(x(1))/(par_r1_p2+(x(1)));
   R1 = par_r2_p1*(x(2))/(par_r2_p2+(x(2)));
   R2 = par_r3_p2*(x(3))/(par_r3_p1+(x(3)));
   R3 = par_r4_p2*(x(4))/(par_r4_p1+(x(4)));
   R4 = par_r5_p2*(x(5))/(par_r5_p1+(x(5)));
   R5 = par_r6_p2*(x(6))/(par_r6_p1+(x(6)));
   R6 = par_r7_p2*(x(7))/(par_r7_p1+(x(7)));
   R7 = par_r8_p2*(x(8))/(par_r8_p1+(x(8)));
   R8 = par_r9_p2*(x(8))/(par_r9_p1+(x(8)));
   R9 = par_r10_p2*(x(9))/(par_r10_p1+(x(9)));
   R10 = par_r11_p2*(x(10))/(par_r11_p1+(x(10)));
   R11 = par_r12_p2*(x(11))/(par_r12_p1+(x(11)));
   R12 = par_r13_p2*(x(12))/(par_r13_p1+(x(12)));
   R13 = par_r14_p2*(x(13))/(par_r14_p1+(x(13)));
   R14 = par_r15_p1*(x(12));
   R15 = par_r16_p1*(x(13));
   R16 = par_r17_p1*(x(14));

   xdot = [
      R0-R0
      R0 - R1
      R1 - R2
      R2 - R3
      R3 - R4
      R4 - R5
      R5 - R6 + R7
      R6 - R7 - R8
      R8 - R9
      R9 - R10
      R10 - R11
      R11 - R12 - R14
      R12 - R13 - R15
      R13 - R16
      R14
      R15
      R16
      0
      0
      0
      0
      0
      0
      0
      0
      0
      0
      0
      0
      0
      ];
end;
